summaryrefslogtreecommitdiffstats
path: root/ui/base/ime/input_method_chromeos.h
diff options
context:
space:
mode:
authorjennyz <jennyz@chromium.org>2014-10-23 14:52:41 -0700
committerCommit bot <commit-bot@chromium.org>2014-10-23 21:53:01 +0000
commit91b6ed0c33013c73e91b5c8c8be57f340a76f7a6 (patch)
tree0537f8efcb4e0b9dffb87fa6ffe25f75fb4eb4ae /ui/base/ime/input_method_chromeos.h
parent0dd094342a90d81ce1e25f2db110bfe51c76d478 (diff)
downloadchromium_src-91b6ed0c33013c73e91b5c8c8be57f340a76f7a6.zip
chromium_src-91b6ed0c33013c73e91b5c8c8be57f340a76f7a6.tar.gz
chromium_src-91b6ed0c33013c73e91b5c8c8be57f340a76f7a6.tar.bz2
Magnifier needs to follow the focus and caret change of the textfield.
BUG=426232 Review URL: https://codereview.chromium.org/665903003 Cr-Commit-Position: refs/heads/master@{#300955}
Diffstat (limited to 'ui/base/ime/input_method_chromeos.h')
-rw-r--r--ui/base/ime/input_method_chromeos.h6
1 files changed, 4 insertions, 2 deletions
diff --git a/ui/base/ime/input_method_chromeos.h b/ui/base/ime/input_method_chromeos.h
index a09cd3d..1022b04 100644
--- a/ui/base/ime/input_method_chromeos.h
+++ b/ui/base/ime/input_method_chromeos.h
@@ -112,8 +112,10 @@ class UI_BASE_EXPORT InputMethodChromeOS
// Callback function for IMEEngineHandlerInterface::ProcessKeyEvent.
void ProcessKeyEventDone(uint32 id, ui::KeyEvent* event, bool is_handled);
- // Returns whether an input field is focused. Note that password field is not
- // considered as an input field.
+ // Returns whether an non-password input field is focused.
+ bool IsNonPasswordInputFieldFocused();
+
+ // Returns true if an text input field is focused.
bool IsInputFieldFocused();
// All pending key events. Note: we do not own these object, we just save